@@ -112,6 +112,7 @@
     rust_2018_idioms,
     future_incompatible,
     nonstandard_style,
+    missing_debug_implementations,
     missing_docs
 )]
 #![deny(unreachable_pub, private_in_public)]
@@ -119,7 +120,7 @@
 #![cfg_attr(docsrs, feature(doc_cfg))]
 
 mod server;
-pub(crate) mod util;
+mod util;
 
 pub use server::{bind, Handle, Server};
 
