@@ -1,13 +1,23 @@
-#[cfg(feature = "tls-rustls")]
-#[cfg_attr(docsrs, doc(cfg(feature = "tls-rustls")))]
-pub mod tls;
-
-#[cfg(feature = "record")]
-#[cfg_attr(docsrs, doc(cfg(feature = "record")))]
-pub mod record;
-
-mod http_server;
-mod socket_addrs;
+use self::http_server::HttpServer;
+use crate::util::HyperService;
+use futures_util::stream::{FuturesUnordered, StreamExt};
+use http::{uri::Scheme, Request, Response};
+use http_body::Body;
+use parking_lot::RwLock;
+use std::{
+    future::Future,
+    io::{self, ErrorKind},
+    net::{SocketAddr, ToSocketAddrs},
+    sync::Arc,
+};
+use tokio::{
+    io::{AsyncRead, AsyncWrite},
+    net::{TcpListener, TcpStream},
+    sync::Notify,
+    task::{spawn_blocking, JoinHandle},
+};
+use tower_layer::Layer;
+use tower_service::Service;
 
 #[cfg(feature = "tls-rustls")]
 use {
@@ -16,57 +26,26 @@ use {
     tls::{TlsLoader, TlsServer},
 };
 
-use http_server::HttpServer;
-use socket_addrs::ToSocketAddrsExt;
+mod http_server;
+mod socket_addrs;
 
-use crate::util::HyperService;
+#[cfg(feature = "tls-rustls")]
+#[cfg_attr(docsrs, doc(cfg(feature = "tls-rustls")))]
+pub mod tls;
 
-use std::future::Future;
-use std::io;
-use std::io::ErrorKind;
-use std::net::{SocketAddr, ToSocketAddrs};
-use std::sync::Arc;
-
-use parking_lot::RwLock;
-
-use futures_util::stream::{FuturesUnordered, StreamExt};
-
-use tokio::io::{AsyncRead, AsyncWrite};
-use tokio::net::{TcpListener, TcpStream};
-use tokio::sync::Notify;
-use tokio::task::{spawn_blocking, JoinHandle};
-
-use http::request::Request;
-use http::response::Response;
-use http::uri::Scheme;
-use http_body::Body;
-
-use tower_layer::Layer;
-use tower_service::Service;
+#[cfg(feature = "record")]
+#[cfg_attr(docsrs, doc(cfg(feature = "record")))]
+pub mod record;
 
 type ListenerTask = JoinHandle<io::Result<()>>;
 type FutList = FuturesUnordered<ListenerTask>;
 
-pub(crate) trait MakeParts {
-    type Layer;
-    type Acceptor;
-
-    fn make_parts(&self) -> (Self::Layer, Self::Acceptor);
-}
-
-pub(crate) trait Accept<I = TcpStream>: Clone + Send + Sync + 'static {
-    type Conn: AsyncRead + AsyncWrite + Unpin + Send + 'static;
-    type Future: Future<Output = io::Result<Self::Conn>> + Send;
-
-    fn accept(&self, conn: I) -> Self::Future;
-}
-
 /// Configurable HTTP server, supporting HTTP/1.1 and HTTP2.
 ///
 /// `Server` can conveniently be turned into a [`TlsServer`](TlsServer) with related methods.
 ///
 /// See [main](crate) page for HTTP example. See [`axum_server::tls`](tls) module for HTTPS example.
-#[derive(Default)]
+#[derive(Debug, Default)]
 pub struct Server {
     addrs: Vec<socket_addrs::Boxed>,
     handle: Handle,
@@ -86,10 +65,9 @@ impl Server {
         A: ToSocketAddrs<Iter = I> + Send + 'static,
         I: Iterator<Item = SocketAddr> + 'static,
     {
-        self.addrs.push(Box::new(addr.map(|iter| {
-            let box_iter: socket_addrs::BoxedIterator = Box::new(iter);
-            box_iter
-        })));
+        let boxed = socket_addrs::Boxed::new(addr);
+
+        self.addrs.push(boxed);
         self
     }
 
@@ -304,12 +282,12 @@ where
 ///     handle.shutdown();
 /// }
 /// ```
-#[derive(Default, Clone)]
+#[derive(Clone, Debug, Default)]
 pub struct Handle {
     inner: Arc<HandleInner>,
 }
 
-#[derive(Default)]
+#[derive(Debug, Default)]
 struct HandleInner {
     listening: Notify,
     listening_addrs: RwLock<Option<Vec<SocketAddr>>>,
@@ -374,6 +352,20 @@ impl Handle {
     }
 }
 
+pub(crate) trait MakeParts {
+    type Layer;
+    type Acceptor;
+
+    fn make_parts(&self) -> (Self::Layer, Self::Acceptor);
+}
+
+pub(crate) trait Accept<I = TcpStream>: Clone + Send + Sync + 'static {
+    type Conn: AsyncRead + AsyncWrite + Unpin + Send + 'static;
+    type Future: Future<Output = io::Result<Self::Conn>> + Send;
+
+    fn accept(&self, conn: I) -> Self::Future;
+}
+
 async fn serve<F, Fut>(fut: F) -> io::Result<()>
 where
     F: FnOnce(FutList) -> Fut,
@@ -443,15 +435,14 @@ pub(crate) fn collect_addrs(
 #[cfg(test)]
 pub(crate) mod tests {
     use super::{bind, collect_addrs, Handle, Server};
-
     use axum::handler::get;
     use http::{Request, Response};
-    use hyper::client::conn::{handshake, SendRequest};
-    use hyper::Body;
-    use std::io;
-    use std::net::SocketAddr;
-    use tokio::net::TcpStream;
-    use tokio::task::JoinHandle;
+    use hyper::{
+        client::conn::{handshake, SendRequest},
+        Body,
+    };
+    use std::{io, net::SocketAddr};
+    use tokio::{net::TcpStream, task::JoinHandle};
     use tower_service::Service;
     use tower_util::ServiceExt;
 
@@ -468,7 +459,6 @@ pub(crate) mod tests {
         s.parse().unwrap()
     }
 
-    #[ignore]
     #[tokio::test]
     async fn test_listening_addrs() {
         let app = get(|| async { "Hello, world!" });
@@ -486,7 +476,6 @@ pub(crate) mod tests {
         assert!(handle.listening_addrs().is_some());
     }
 
-    #[ignore]
     #[tokio::test]
     async fn test_with_requests() {
         let app = get(|| async { "Hello, world!" });
@@ -516,7 +505,6 @@ pub(crate) mod tests {
         }
     }
 
-    #[ignore]
     #[tokio::test]
     async fn test_shutdown() {
         let app = get(|| async { "Hello, world!" });
@@ -559,7 +547,6 @@ pub(crate) mod tests {
         }
     }
 
-    #[ignore]
     #[tokio::test]
     async fn test_graceful_shutdown() {
         let app = get(|| async { "Hello, world!" });
