@@ -54,43 +54,40 @@
 //! }
 //! ```
 
-use crate::server::http_server::HttpServer;
-use crate::server::socket_addrs::{self, ToSocketAddrsExt};
-use crate::server::{serve, serve_addrs, Accept, Handle, MakeParts, Server};
-
-use crate::util::HyperService;
-
-use std::fs::File;
-use std::io;
-use std::io::{BufRead, BufReader, Cursor, ErrorKind, Seek, SeekFrom};
-use std::net::{SocketAddr, ToSocketAddrs};
-use std::path::{Path, PathBuf};
-use std::sync::Arc;
-
-use parking_lot::RwLock;
-
-use tokio::io::{AsyncRead, AsyncWrite};
-use tokio::task::spawn_blocking;
-
-use rustls::{
-    internal::pemfile::certs, internal::pemfile::pkcs8_private_keys,
-    internal::pemfile::rsa_private_keys, Certificate, NoClientAuth, PrivateKey, ServerConfig,
+use crate::{
+    server::{
+        http_server::HttpServer, serve, serve_addrs, socket_addrs, Accept, Handle, MakeParts,
+        Server,
+    },
+    util::HyperService,
 };
-
-use tokio_rustls::{server::TlsStream, Accept as AcceptFuture, TlsAcceptor as CoreTlsAcceptor};
-
-use http::request::Request;
-use http::response::Response;
-use http::uri::Scheme;
+use http::{uri::Scheme, Request, Response};
 use http_body::Body;
-
+use parking_lot::RwLock;
+use rustls::{
+    internal::pemfile::{certs, pkcs8_private_keys, rsa_private_keys},
+    Certificate, NoClientAuth, PrivateKey, ServerConfig,
+};
+use std::{
+    fmt,
+    fs::File,
+    io::{self, BufRead, BufReader, Cursor, ErrorKind, Seek, SeekFrom},
+    net::{SocketAddr, ToSocketAddrs},
+    path::{Path, PathBuf},
+    sync::Arc,
+};
+use tokio::{
+    io::{AsyncRead, AsyncWrite},
+    task::spawn_blocking,
+};
+use tokio_rustls::{server::TlsStream, Accept as AcceptFuture, TlsAcceptor as CoreTlsAcceptor};
 use tower_layer::Layer;
 use tower_service::Service;
 
 /// Configurable HTTP and HTTPS server, supporting HTTP/1.1 and HTTP2.
 ///
 /// See [module](crate::server::tls) page for examples.
-#[derive(Default)]
+#[derive(Debug, Default)]
 pub struct TlsServer {
     server: Server,
     tls_addrs: Vec<socket_addrs::Boxed>,
@@ -128,10 +125,9 @@ impl TlsServer {
         A: ToSocketAddrs<Iter = I> + Send + 'static,
         I: Iterator<Item = SocketAddr> + 'static,
     {
-        self.tls_addrs.push(Box::new(addr.map(|iter| {
-            let box_iter: socket_addrs::BoxedIterator = Box::new(iter);
-            box_iter
-        })));
+        let boxed = socket_addrs::Boxed::new(addr);
+
+        self.tls_addrs.push(boxed);
         self
     }
 
@@ -370,7 +366,7 @@ impl From<Server> for TlsServer {
 ///     }
 /// }
 /// ```
-#[derive(Default, Clone)]
+#[derive(Clone, Default)]
 pub struct TlsLoader {
     server_config: Option<Arc<ServerConfig>>,
     private_key: Option<Vec<u8>>,
@@ -380,6 +376,17 @@ pub struct TlsLoader {
     acceptor: Option<Arc<RwLock<CoreTlsAcceptor>>>,
 }
 
+impl fmt::Debug for TlsLoader {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_struct("TlsLoader")
+            .field("private_key", &self.private_key)
+            .field("certificate", &self.certificate)
+            .field("private_key_path", &self.private_key_path)
+            .field("certificate_path", &self.certificate_path)
+            .finish()
+    }
+}
+
 impl TlsLoader {
     /// Create a `TlsLoader`.
     pub fn new() -> Self {
@@ -593,6 +600,27 @@ where
 
 #[cfg(test)]
 pub(crate) mod tests {
+    use super::{cert_from_value, pkey_from_value, rustls_config, Handle};
+    use crate::server::{
+        bind_rustls, collect_addrs,
+        tests::{empty_request, into_text},
+        Server,
+    };
+    use axum::handler::get;
+    use hyper::{
+        client::conn::{handshake, SendRequest},
+        Body,
+    };
+    use rustls::{
+        Certificate, ClientConfig, RootCertStore, ServerCertVerified, ServerCertVerifier, TLSError,
+    };
+    use std::{io, net::SocketAddr, sync::Arc};
+    use tokio::net::TcpStream;
+    use tokio_rustls::TlsConnector;
+    use tower_service::Service;
+    use tower_util::ServiceExt;
+    use webpki::DNSNameRef;
+
     // Self Signed Certificate
     pub(crate) const CERTIFICATE: &'static str = r#"-----BEGIN CERTIFICATE-----
 MIIDkzCCAnugAwIBAgIUaVoRuh53PqMETXoouyFrcDmZeSkwDQYJKoZIhvcNAQEL
@@ -647,28 +675,6 @@ ZOwXFVl9mCxXHeYG/tnW4TStiro0hP3lwGUKPaFcR3vHbXLoDrmLycMLP13eOCSt
 SfyHiEc0jh9LdjUlMvCXaB8=
 -----END PRIVATE KEY-----"#;
 
-    use super::{cert_from_value, pkey_from_value, rustls_config, Handle};
-
-    use crate::server::{
-        bind_rustls, collect_addrs,
-        tests::{empty_request, into_text},
-        Server,
-    };
-
-    use axum::handler::get;
-    use hyper::client::conn::{handshake, SendRequest};
-    use hyper::Body;
-    use rustls::ClientConfig;
-    use rustls::{Certificate, RootCertStore, ServerCertVerified, ServerCertVerifier, TLSError};
-    use std::io;
-    use std::net::SocketAddr;
-    use std::sync::Arc;
-    use tokio::net::TcpStream;
-    use tokio_rustls::TlsConnector;
-    use tower_service::Service;
-    use tower_util::ServiceExt;
-    use webpki::DNSNameRef;
-
     struct TestCertVerifier;
 
     impl ServerCertVerifier for TestCertVerifier {
@@ -712,7 +718,6 @@ SfyHiEc0jh9LdjUlMvCXaB8=
         s.parse().unwrap()
     }
 
-    #[ignore]
     #[tokio::test]
     async fn test_listening_addrs() {
         let key = PRIVATE_KEY.as_bytes().to_vec();
@@ -735,7 +740,6 @@ SfyHiEc0jh9LdjUlMvCXaB8=
         assert!(handle.listening_addrs().is_some());
     }
 
-    #[ignore]
     #[tokio::test]
     async fn test_with_requests() {
         let key = PRIVATE_KEY.as_bytes().to_vec();
